//----------------------------------------------------------------------------//
//----------------------------------------------------------------------------//
//--- Before Starting
//----------------------------------------------------------------------------//
//----------------------------------------------------------------------------//

//-----------------------------------//
//--- Necessary Packages
//-----------------------------------//

ssc install estout
ssc install estwrite
ssc install coefplot

//-----------------------------------//
//--- Data
//-----------------------------------//

// Data

use "../workingdata/wrkdt", clear
desc

// Variables

sum [aw=wt]

//-----------------------------------//
//--- Macros
//-----------------------------------//

// Typing all

reg wage i.fem c.age##c.age i.red i.rra i.mst i.year [pw=wt]
eststo m1

// Set up globals & locals

global dv wage
local ctr1 c.age##c.age i.red i.rra i.mst i.year

reg $dv i.fem `ctr1' [pw=wt]
eststo m1

//-----------------------------------//
//--- How information is stored
//-----------------------------------//

ereturn list

//-----------------------------------//
//--- How coefficient is stored
//-----------------------------------//

mat list e(b)

//-----------------------------------//
//--- Grab coefficient
//-----------------------------------//

di _b[1.fem]

//----------------------------------------------------------------------------//
//----------------------------------------------------------------------------//
//--- Running and Saving Regressions
//----------------------------------------------------------------------------//
//----------------------------------------------------------------------------//

//-----------------------------------//
//--- Utilize loops #1
//-----------------------------------//

// Different models

local ctr1 c.age##c.age i.rra i.mst i.year
local ctr2 c.age##c.age i.rra i.mst i.year i.red

reg $dv i.fem `ctr1' [pw=wt]
eststo m1

reg $dv i.fem `ctr2' [pw=wt]
eststo m2

// Loop over models

local ctr1 c.age##c.age i.rra i.mst i.year
local ctr2 c.age##c.age i.rra i.mst i.year i.red

foreach md in 1 2 {
  reg $dv i.fem `ctr`md'' [pw=wt]
  eststo m`md'
}

//-----------------------------------//
//------ Results
//-----------------------------------//

esttab m1 m2, ///
  mtitle(m1 m2) ///
  b(3) se(3) r2(3) ar2(3) keep(*.fem) lab

//-----------------------------------//
//--- Utilize loops #2
//-----------------------------------//

// Same model for multiple years

local ctr3 c.age##c.age i.rra i.mst

reg $dv i.fem `ctr3' [pw=wt] if year == 2000
eststo m3_y2000

reg $dv i.fem `ctr3' [pw=wt] if year == 2010
eststo m3_y2010

reg $dv i.fem `ctr3' [pw=wt] if year == 2019
eststo m3_y2019

// Loop same model over years

local ctr3 c.age##c.age i.rra i.mst

foreach y in 2000 2010 2019 {
  reg $dv i.fem `ctr3' [pw=wt] if year == `y'
  eststo m3_y`y'
}

//-----------------------------------//
//--- Results
//-----------------------------------//

esttab m3_y2000 m3_y2010 m3_y2019, ///
  mtitle(y2000 y2010 y2019) ///
  b(3) se(3) r2(3) ar2(3) keep(*.fem) lab

//-----------------------------------//
//--- Loops can be nested
//-----------------------------------//

// Loop over each model & each year

local ctr3 c.age##c.age i.rra i.mst
local ctr4 c.age##c.age i.rra i.mst i.red

foreach md in 3 4 {
  foreach y in 2000 2010 2019 {
    reg $dv i.fem `ctr`md'' [pw=wt] if year == `y'
    eststo m`md'_y`y'
  }
}

//-----------------------------------//
//--- What if there are lots of years?
//-----------------------------------//

// Put values of variable year into local yrs and loop over each

levelsof year, local(yrs)

local ctr3 c.age##c.age i.rra i.mst

foreach y in `yrs' {
  reg $dv i.fem `ctr3' [pw=wt] if year == `y'
  eststo m3_y`y'
}

// Same results, different way to loop

levelsof year, local(yrs)
local yrsn : word count `yrs'

local ctr3 c.age##c.age i.rra i.mst

forvalues i = 1(1)`yrsn' {
  local y : word `i' of `yrs'

  reg $dv i.fem `ctr3' [pw=wt] if year == `y'
  eststo m3_y`y'
}

//-----------------------------------//
//--- Loop over models and years
//-----------------------------------//

levelsof year, local(yrs)
local yrsn : word count `yrs'

local ctr3 c.age##c.age i.rra i.mst
local ctr4 c.age##c.age i.rra i.mst i.red

foreach md in 3 4 {
  forvalues i = 1(1)`yrsn' {
  	local y : word `i' of `yrs'
    reg $dv i.fem `ctr`md'' [pw=wt] if year == `y'
    eststo m`md'_y`y'
  }
}

//-----------------------------------//
//--- Save results
//-----------------------------------//

// Save all stored estimates through eststo

estwrite * using "../estimates/results", replace

// Save the results with names that starts with m4

estwrite m4_* using "../estimates/results_m4", replace

//----------------------------------------------------------------------------//
//----------------------------------------------------------------------------//
//--- Load and Plot Estimates
//----------------------------------------------------------------------------//
//----------------------------------------------------------------------------//

//-----------------------------------//
//--- Load/Read
//-----------------------------------//

estread using "../estimates/results"

//-----------------------------------//
//--- coefplot: typical usage
//-----------------------------------//

coefplot m4_y2000, ///
  keep(*.red) lab xtitle("Coefficient (ref. LTHS)") xsize(7) ysize(4) name(fig1, replace)

//-----------------------------------//
//--- coefplot: typical usage, multiple years
//-----------------------------------//

coefplot m4_y2000 m4_y2019, ///
  keep(*.red) lab xtitle("Coefficient (ref. LTHS)") xsize(7) ysize(4) name(fig2, replace) ///
  legend(label(2 "2000") label(4 "2019"))

//-----------------------------------//
//--- Plot coefficient for each year (2000 to 2019), Prep
//-----------------------------------//

levelsof year, local(yrs)
local row : word count `yrs'
local col = 4

mat define m3 = J(`row', `col', .)
mat colnames m3 = year b ci_l ci_u

mat list m3

forvalues i = 1(1)`row' {
	local y : word `i' of `yrs'
	
	est res m3_y`y'
	
	mat m3[`i', 1] = `y'
	mat m3[`i', 2] = _b[1.fem]
	mat m3[`i', 3] = _b[1.fem] - invttail(e(df_r),0.025)*_se[1.fem]
	mat m3[`i', 4] = _b[1.fem] + invttail(e(df_r),0.025)*_se[1.fem]
}

mat list m3

//-----------------------------------//
//--- Plot coefficient for each year (2000 to 2019)
//-----------------------------------//

coefplot (matrix(m3[, 2]), ci((m3[, 3] m3[, 4])) ), at(matrix(m3[, 1])) ///
  vert recast(connected) ytitle("Gender Gap in Log Hourly Wage") xsize(7) ysize(4) ///
  name(fig3, replace)

//-----------------------------------//
//--- Plot multiple models
//-----------------------------------//

levelsof year, local(yrs)
local row : word count `yrs'
local col = 4

mat define m4 = J(`row', `col', .)
mat colnames m4 = year b ci_l ci_u

forvalues i = 1(1)`row' {
	local y : word `i' of `yrs'
	
	est res m4_y`y'
	
	mat m4[`i', 1] = `y'
	mat m4[`i', 2] = _b[1.fem]
	mat m4[`i', 3] = _b[1.fem] - invttail(e(df_r),0.025)*_se[1.fem]
	mat m4[`i', 4] = _b[1.fem] + invttail(e(df_r),0.025)*_se[1.fem]
}

//-----------------------------------//
//--- Plot gender gap for each year (2000 to 2019), m3 & m4
//-----------------------------------//

coefplot (matrix(m3[, 2]), ci((m3[, 3] m3[, 4])) ) (matrix(m4[, 2]), ci((m4[, 3] m4[, 4])) ), ///
  at(matrix(m3[, 1])) ///
  vert recast(connected) ytitle("Gender Gap in Log Hourly Wage") ///
  legend(label(2 "Model 3") label(4 "Model 4")) xsize(7) ysize(4) ///
  name(fig4, replace)

coefplot (matrix(m3[, 2]), ci((m3[, 3] m3[, 4])) ) (matrix(m4[, 2]), ci((m4[, 3] m4[, 4])) ), ///
  at(matrix(m3[, 1])) ciopts(recast(rarea) fcolor(%20) lcolor(%0)) ///
  vert recast(connected) ytitle("Gender Gap in Log Hourly Wage") ///
  legend(label(2 "Model 3") label(4 "Model 4")) xsize(7) ysize(4) ///
  name(fig5, replace)

texdoc stlog, beamer
coefplot (matrix(m3[, 2]), ci((m3[, 3] m3[, 4])) ), bylabel("Model 3") ///
  || (matrix(m4[, 2]), ci((m4[, 3] m4[, 4])) ), bylabel("Model 4") ///
  at(matrix(m3[, 1])) vert recast(connected) ytitle("Gender Gap in Log Hourly Wage") ///
  byopts(rows(1)) xsize(7) ysize(4) ///
  name(fig6, replace)

  
//----------------------------------------------------------------------------//
//----------------------------------------------------------------------------//
//--- Schemes and Saving Graphs
//----------------------------------------------------------------------------//
//----------------------------------------------------------------------------//

//-----------------------------------//
//--- Scheme: plotUPenn
//-----------------------------------//

help scheme
net install plotUPenn, from("https://atkim1103.github.io/website/files/plotUPenn")

//-----------------------------------//
//--- Scheme: cleanplots
//-----------------------------------//

net install cleanplots, from("https://tdmize.github.io/data/cleanplots")

//-----------------------------------//
//--- Scheme: s2color
//-----------------------------------//

set scheme s2color

coefplot (matrix(m3[, 2]), ci((m3[, 3] m3[, 4])) ) (matrix(m4[, 2]), ci((m4[, 3] m4[, 4])) ), ///
  at(matrix(m3[, 1])) vert recast(connected) ytitle("Gender Gap in Log Hourly Wage") ///
  legend(label(2 "Model 3") label(4 "Model 4")) ///
  ciopts(recast(rarea) fcolor(%20) lcolor(%0)) xsize(7) ysize(4) name(fig7, replace)

//-----------------------------------//
//--- Scheme: sj, Stata Journal
//-----------------------------------//

set scheme sj

set scheme sj
coefplot (matrix(m3[, 2]), ci((m3[, 3] m3[, 4])) ) (matrix(m4[, 2]), ci((m4[, 3] m4[, 4])) ), ///
  at(matrix(m3[, 1])) vert recast(connected) ytitle("Gender Gap in Log Hourly Wage") ///
  legend(label(2 "Model 3") label(4 "Model 4")) ///
  ciopts(recast(rarea) fcolor(%20) lcolor(%0)) xsize(7) ysize(4) name(fig8, replace)

//-----------------------------------//
//--- Scheme: cleanplots
//-----------------------------------//

set scheme cleanplots

coefplot (matrix(m3[, 2]), ci((m3[, 3] m3[, 4])) ) (matrix(m4[, 2]), ci((m4[, 3] m4[, 4])) ), ///
  at(matrix(m3[, 1])) vert recast(connected) ytitle("Gender Gap in Log Hourly Wage") ///
  legend(label(2 "Model 3") label(4 "Model 4")) ///
  ciopts(recast(rarea) fcolor(%20) lcolor(%0)) xsize(7) ysize(4) name(fig9, replace)

coefplot (matrix(m3[, 2]), ci((m3[, 3] m3[, 4])) ) (matrix(m4[, 2]), ci((m4[, 3] m4[, 4])) ), ///
  at(matrix(m3[, 1])) vert recast(connected) ytitle("Gender Gap in Log Hourly Wage") ///
  legend(label(2 "Model 3") label(4 "Model 4") pos(6) rows(1)) ///
  ciopts(recast(rarea) fcolor(%20) lcolor(%0)) xsize(7) ysize(4) name(fig10, replace)

//-----------------------------------//
//--- Scheme: plotUPenn
//-----------------------------------//

set scheme plotUPenn

coefplot (matrix(m3[, 2]), ci((m3[, 3] m3[, 4])) ) (matrix(m4[, 2]), ci((m4[, 3] m4[, 4])) ), ///
  at(matrix(m3[, 1])) vert recast(connected) ytitle("Gender Gap in Log Hourly Wage") ///
  legend(label(2 "Model 3") label(4 "Model 4") pos(6) rows(1)) ///
  ciopts(recast(rarea) fcolor(%20) lcolor(%0)) xsize(7) ysize(4) name(fig11, replace)
  
//-----------------------------------//
//--- Saving Graphs
//-----------------------------------//

forvalues i = 1(1)11 {
	gr export "../table_figure/fig`i'.pdf", name(fig`i') replace
}

//----------------------------------------------------------------------------//
//----------------------------------------------------------------------------//
//--- Put coefficient from multiple years into a single model
//----------------------------------------------------------------------------//
//----------------------------------------------------------------------------//

capt prog drop appendmd
prog appendmd, eclass
	// assuming that last element in e(b)/e(V) is not _cons
	version 8
	syntax namelist
	tempname b V tmp
	foreach name of local namelist {
		qui est restore `name'
		mat `b' = nullmat(`b') , e(b)
		mat `b' = `b'[1,1..colsof(`b')]
		mat `tmp' = e(V)
		mat `tmp' = `tmp'[1..rowsof(`tmp'),1..colsof(`tmp')]
		capt confirm matrix `V'
		if _rc {
			mat `V' = `tmp'
		}
		else {
			mat `V' = ///
				( `V' , J(rowsof(`V'),colsof(`tmp'),0) ) \ ///
				( J(rowsof(`tmp'),colsof(`V'),0) , `tmp' )
		}
	}
	local names: colfullnames `b'
	mat coln `V' = `names'
	mat rown `V' = `names'
	eret post `b' `V'
	eret local cmd "whatever"
end

levelsof year, local(yrs)

foreach y in `yrs' {
	est res m3_y`y'

	local fem_coln = colnumb(e(b), "1.fem")
	local fem_rown = colnumb(e(V), "1.fem")

	mat b = e(b)[1, `fem_coln']
	mat v = e(V)[`fem_rown', `fem_coln']

	mat colnames b = "y`y'"
	mat colnames v = "y`y'"
	mat rownames v = "y`y'"

	ereturn post b v
	eststo y`y'
}

levelsof year, local(yrs)
local yrsn : word count `yrs'

local mods "y2000"
forvalues i = 2(1)`yrsn' {
	local y : word `i' of `yrs'
	local mods "`mods' y`y'"
}

appendmd `mods'
eststo m3_fem

coefplot m3_fem, ///
	vert recast(connected) ytitle("Gender Gap in Log Hourly Wage") ///
	xlabel(1 "2000" 6 "2005" 11 "2010" 16 "2015" 21 "2020", grid) ///
	name(fig12, replace)
